@@ -14,20 +14,24 @@ class litUesr:
         self.username = username
         self.password = util.get_sha256(password)
 
-        # login the acconut
-        self.info = self.__login()
+        self.__headers = {
+            'Connection': 'keep-alive',
+            'Content-Type': 'application/json'
+        }
+
         try:
-            self.token = self.info['token']
+            # login the acconut
+            self.info = self.__login()['data']
+        except:
+            self.info = None
+
+        try:
+            self.__headers['token'] = self.info['token']
             self.is_logined = True
         except:
             self.is_logined = False
 
     def __login(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json'
-        }
-
         data = {
             'cardNo': self.username,
             'password': self.password
@@ -36,7 +40,7 @@ class litUesr:
         # login func
         try:
             response = requests.post(
-                url=endpoints['login'], data=json.dumps(data), headers=headers)
+                url=endpoints['login'], data=json.dumps(data), headers=self.__headers)
         except:
             return None
 
@@ -45,12 +49,6 @@ class litUesr:
         return res
 
     def get_last_record(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json',
-            'token': self.token
-        }
-
         data = {
             'teamId': self.info['teamId'],
             'userId': self.info['userId']
@@ -58,7 +56,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints['lastRecord'], params=data, headers=headers)
+                url=endpoints['lastRecord'], params=data, headers=self.__headers)
         except:
             return None
 
@@ -67,20 +65,15 @@ class litUesr:
         return res
 
     def get_instructor(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
-
         data = {
             'teamId': self.info['teamId'],
             'organizationName': self.info['organizationName'],
             'userOrganizationId': self.info['userOrganizationId']
         }
+
         try:
             response = requests.get(
-                url=endpoints['getInstructor'], params=data, headers=headers)
+                url=endpoints['getInstructor'], params=data, headers=self.__headers)
         except:
             return None
 
@@ -89,19 +82,13 @@ class litUesr:
         return res
 
     def get_familys(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
-
         data = {
             'userId': self.info['userId'],
         }
 
         try:
             response = requests.get(
-                url=endpoints['getFamilys'], params=data, headers=headers)
+                url=endpoints['getFamilys'], params=data, headers=self.__headers)
         except:
             return None
 
@@ -110,15 +97,9 @@ class litUesr:
         return res
 
     def get_important_city(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
-
         try:
             response = requests.get(
-                url=endpoints['getImportantCity'], headers=headers)
+                url=endpoints['getImportantCity'], headers=self.__headers)
         except:
             return None
 
@@ -126,12 +107,6 @@ class litUesr:
         return res
 
     def get_trips(self):
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
-
         data = {
             'userId': self.info['userId'],
             'teamId': self.info['teamId'],
@@ -139,7 +114,7 @@ class litUesr:
 
         try:
             response = requests.get(
-                url=endpoints['getTrips'], params=data, headers=headers)
+                url=endpoints['getTrips'], params=data, headers=self.__headers)
         except:
             return None
 
@@ -147,19 +122,14 @@ class litUesr:
 
         return res
 
-    def first_record(self, mode='last', times=1, temperature=36.6, temperatureTwo=36.3, temperatureThree=36.3):
+    def first_record(self, mode='last', times=1, temperature=36.1, temperatureTwo=36.2, temperatureThree=36.3):
         """
         the 'normal' will not record the temperatureTwo and temperatureThree values from last record
         and you can use the 'manual' for use your values, 'random' use random values
         """
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
 
         # get the last record info
-        last_record = self.get_last_record()
+        last_record = self.get_last_record()['data']
 
         data = {
             'mobile': self.info['mobile'],
@@ -236,7 +206,7 @@ class litUesr:
 
         try:
             response = requests.post(
-                url=endpoints['firstRecord'], data=json.dumps(data), headers=headers)
+                url=endpoints['firstRecord'], data=json.dumps(data), headers=self.__headers)
             # res['data']['temperature'] = data['temperature']
             # res['data']['temperatureTwo'] = data['temperatureTwo']
             # res['data']['temperatureThree'] = data['temperatureThree']
@@ -258,14 +228,9 @@ class litUesr:
         """
         mode: 'last', 'random' and 'manual'
         """
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
 
         # get the last record info
-        last_record = self.get_last_record()
+        last_record = self.get_last_record()['data']
 
         data = {
             'healthyRecordId': last_record['id'],
@@ -284,7 +249,7 @@ class litUesr:
 
         try:
             response = requests.put(
-                url=endpoints['secondRecord'], params=data, headers=headers)
+                url=endpoints['secondRecord'], params=data, headers=self.__headers)
         except:
             return None
 
@@ -297,14 +262,9 @@ class litUesr:
         """
         mode: 'last', 'random' and 'manual'
         """
-        headers = {
-            'Connection': 'keep-alive',
-            'Content-Type': 'application/json;charset=UTF-8',
-            'token': self.token,
-        }
 
         # get the last record info
-        last_record = self.get_last_record()
+        last_record = self.get_last_record()['data']
 
         data = {
             'healthyRecordId': last_record['id'],
@@ -323,11 +283,11 @@ class litUesr:
 
         try:
             response = requests.put(
-                url=endpoints['thirdRecord'], params=data, headers=headers)
+                url=endpoints['thirdRecord'], params=data, headers=self.__headers)
         except:
             return None
 
         res = response.json()
         res['data'] = {'temperature': data['temperature']}
 
-        return res
\ No newline at end of file
+        return res
